==> nomachine-7.6.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXSessionManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXSessionManager::BEGIN{package NXSessionManager;no warnings;require 
NXSession2;do{"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x32"->import};}package 
NXSessionManager;no warnings;($sessionCloseStarted=(0x03c0+ 2548-0x0db4));sub 
listConnectedSessions{(my (@param)=@_);($sessionId=$param[(0x1722+ 708-0x19e5)])
;($sessionId=~ s/^.*=// );if (($sessionId=~ /(\w{32})$/ )){if ((not (
NXSession2::existSession ($sessionId)))){NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);return ((0x0ce9+ 5695-0x2328));}(my (
@connectedSessions)=NXSession2::listConnectedSessions ($sessionId));
main::nxwrite (main::nxgetSTDOUT (),
"\x0a\x53\x65\x73\x73\x69\x6f\x6e\x73\x49\x64\x0a");main::nxwrite (
main::nxgetSTDOUT (),(("\x2d" x (0x05d1+ 7221-0x21e6))."\x0a"));my ($sessionId);
foreach my $sessionId (@connectedSessions){($sessionId=sprintf (
"\x25\x2d\x33\x32\x73",$sessionId));main::nxwrite (main::nxgetSTDOUT (),(
$sessionId."\x0a"));}Logger::debug (
"\x52\x65\x70\x6f\x72\x74\x65\x64\x20\x64\x61\x74\x61\x20\x74\x6f\x20\x63\x6c\x69\x65\x6e\x74\x2e"
);main::nxwrite (main::nxgetSTDOUT (),"\x0a");return ((0x0934+ 4443-0x1a8e));}
else{if (($sessionId eq (""))){NXMsg::error (
"\x65\x43\x4d\x44\x43\x61\x6e\x6e\x6f\x74\x53\x65\x6c\x65\x63\x74\x53\x65\x73\x73\x69\x6f\x6e\x4d\x69\x73\x73\x69\x6e\x67\x41\x72\x67"
,"\x6d\x61\x69\x6e");}else{NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);}}return ((0x0ccd+ 227-0x0db0));}sub 
listConnectedSessionUsers{(my (@param)=@_);(my $message=(""));if ((
Server::isClientNxwebclient ()or Server::isClientNxclient ())){($sessionId=
$param[(0x055f+ 763-0x085a)]);}else{($sessionId=$param[(0x0eeb+ 2968-0x1a82)]);}
($sessionId=~ s/^.*=// );if (($sessionId=~ /(\w{32})$/ )){if ((not (
NXSession2::existSession ($sessionId)))){NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);return ((0x07cb+ 7583-0x256a));}(my (
@connectedSessions)=NXSession2::listConnectedSessions ($sessionId));
main::nxwrite (main::nxgetSTDOUT (),
"\x55\x73\x65\x72\x6e\x61\x6d\x65\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x0a"
);main::nxwrite (main::nxgetSTDOUT (),(((("\x2d" x (0x0e49+ 1224-0x12f0))."\x20"
).("\x2d" x (0x0979+ 4199-0x19c0)))."\x0a"));foreach my $session (
@connectedSessions){($session=sprintf ("\x25\x2d\x33\x32\x73",$session));(my $username
=NXSession2::getUsernameBySessionId ($session));($username=sprintf (
"\x25\x2d\x33\x33\x73",$username));($message=((($username."\x20").$session).
"\x0a"));main::nxwrite (main::nxgetSTDOUT (),$message);}if ((
Server::isClientNxwebclient ()or Server::isClientNxclient ())){Logger::debug (((
"\x52\x65\x70\x6f\x72\x74\x65\x64\x20\x64\x61\x74\x61\x20\x74\x6f\x20\x63\x6c\x69\x65\x6e\x74\x5b"
.$message)."\x5d\x2e"));}}else{if (($sessionId eq (""))){NXMsg::error (
"\x65\x43\x4d\x44\x43\x61\x6e\x6e\x6f\x74\x53\x65\x6c\x65\x63\x74\x53\x65\x73\x73\x69\x6f\x6e\x4d\x69\x73\x73\x69\x6e\x67\x41\x72\x67"
,"\x6d\x61\x69\x6e");}else{NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);}}return ((0x1297+ 4817-0x2568));}sub 
considerSessionReconnect{if (((Common::NXSessionType::isVirtualAttach (
NXSessionParameters::getSessionType ())and NXSessionParameters::isReconnectable 
())and NXSessionParameters::isRestoreSession ())){return ((0x173a+ 238-0x1827));
}else{return ((0x09f4+ 954-0x0dae));}}sub considerBeforeSessionDisconnect{if ((
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ())and (
not (Server::isMasterGoingToShutdown ())))){NXEvent::beforeSessionDisconnect ();
}}sub considerAfterSessionDisconnect{if ((Common::NXSessionType::isVirtual (
NXSessionParameters::getSessionType ())and (not (Server::isMasterGoingToShutdown
 ())))){NXEvent::afterSessionDisconnect ();}}sub considerBeforeSessionStart{if (
(NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionStart ();}}sub 
considerBeforeSessionClose{if ((((isNotSessionCloseStarted ()and 
NXSessionParameters::getSessionType ())and Common::NXSessionType::isVirtual (
NXSessionParameters::getSessionType ()))or Common::NXSessionType::isAttach (
NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionClose ();}}}sub
 considerAfterSessionClose{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::afterSessionClose ();}}}sub 
considerBeforeSessionFailure{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionFailure ();}}}
sub considerAfterSessionFailure{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::afterSessionFailure ();}}}
sub setSessionCloseStarted{($NXSession::sessionCloseStarted=
(0x1104+ 5502-0x2681));}sub isSessionCloseStarted{return (
$NXSession::sessionCloseStarted);}sub isNotSessionCloseStarted{return ((!
isSessionCloseStarted ()));}return ((0x0131+ 7784-0x1f98));

==> nomachine-7.7.4-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXSessionManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXSessionManager::BEGIN{package NXSessionManager;no warnings;require 
NXSession2;do{"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x32"->import};}package 
NXSessionManager;no warnings;($sessionCloseStarted=(0x1276+ 803-0x1599));sub 
listConnectedSessions{(my (@param)=@_);($sessionId=$param[(0x03e4+ 886-0x0759)])
;($sessionId=~ s/^.*=// );if (($sessionId=~ /(\w{32})$/ )){if ((not (
NXSession2::existSession ($sessionId)))){NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);return ((0x1c34+ 2348-0x2560));}(my (
@connectedSessions)=NXSession2::listConnectedSessions ($sessionId));
main::nxwrite (main::nxgetSTDOUT (),
"\x0a\x53\x65\x73\x73\x69\x6f\x6e\x73\x49\x64\x0a");main::nxwrite (
main::nxgetSTDOUT (),(("\x2d" x (0x0229+ 4292-0x12cd))."\x0a"));my ($sessionId);
foreach my $sessionId (@connectedSessions){($sessionId=sprintf (
"\x25\x2d\x33\x32\x73",$sessionId));main::nxwrite (main::nxgetSTDOUT (),(
$sessionId."\x0a"));}Logger::debug (
"\x52\x65\x70\x6f\x72\x74\x65\x64\x20\x64\x61\x74\x61\x20\x74\x6f\x20\x63\x6c\x69\x65\x6e\x74\x2e"
);main::nxwrite (main::nxgetSTDOUT (),"\x0a");return ((0x004d+ 7865-0x1f05));}
else{if (($sessionId eq (""))){NXMsg::error (
"\x65\x43\x4d\x44\x43\x61\x6e\x6e\x6f\x74\x53\x65\x6c\x65\x63\x74\x53\x65\x73\x73\x69\x6f\x6e\x4d\x69\x73\x73\x69\x6e\x67\x41\x72\x67"
,"\x6d\x61\x69\x6e");}else{NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);}}return ((0x03f0+ 2187-0x0c7b));}sub 
listConnectedSessionUsers{(my (@param)=@_);(my $message=(""));if ((
Server::isClientNxwebclient ()or Server::isClientNxclient ())){($sessionId=
$param[(0x1122+ 5124-0x2526)]);}else{($sessionId=$param[(0x10df+ 4259-0x2181)]);
}($sessionId=~ s/^.*=// );if (($sessionId=~ /(\w{32})$/ )){if ((not (
NXSession2::existSession ($sessionId)))){NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);return ((0x0117+ 8491-0x2242));}(my (
@connectedSessions)=NXSession2::listConnectedSessions ($sessionId));
main::nxwrite (main::nxgetSTDOUT (),
"\x55\x73\x65\x72\x6e\x61\x6d\x65\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x0a"
);main::nxwrite (main::nxgetSTDOUT (),(((("\x2d" x (0x0cea+ 3339-0x19d4))."\x20"
).("\x2d" x (0x08aa+ 6597-0x224f)))."\x0a"));foreach my $session (
@connectedSessions){($session=sprintf ("\x25\x2d\x33\x32\x73",$session));(my $username
=NXSession2::getUsernameBySessionId ($session));($username=sprintf (
"\x25\x2d\x33\x33\x73",$username));($message=((($username."\x20").$session).
"\x0a"));main::nxwrite (main::nxgetSTDOUT (),$message);}if ((
Server::isClientNxwebclient ()or Server::isClientNxclient ())){Logger::debug (((
"\x52\x65\x70\x6f\x72\x74\x65\x64\x20\x64\x61\x74\x61\x20\x74\x6f\x20\x63\x6c\x69\x65\x6e\x74\x5b"
.$message)."\x5d\x2e"));}}else{if (($sessionId eq (""))){NXMsg::error (
"\x65\x43\x4d\x44\x43\x61\x6e\x6e\x6f\x74\x53\x65\x6c\x65\x63\x74\x53\x65\x73\x73\x69\x6f\x6e\x4d\x69\x73\x73\x69\x6e\x67\x41\x72\x67"
,"\x6d\x61\x69\x6e");}else{NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);}}return ((0x0890+ 7141-0x2475));}sub 
considerSessionReconnect{if (((Common::NXSessionType::isVirtualAttach (
NXSessionParameters::getSessionType ())and NXSessionParameters::isReconnectable 
())and NXSessionParameters::isRestoreSession ())){return ((0x07aa+ 6728-0x21f1))
;}else{return ((0x1e82+ 1222-0x2348));}}sub considerBeforeSessionDisconnect{if (
(Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ())and (
not (Server::isMasterGoingToShutdown ())))){NXEvent::beforeSessionDisconnect ();
}}sub considerAfterSessionDisconnect{if ((Common::NXSessionType::isVirtual (
NXSessionParameters::getSessionType ())and (not (Server::isMasterGoingToShutdown
 ())))){NXEvent::afterSessionDisconnect ();}}sub considerBeforeSessionStart{if (
(NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionStart ();}}sub 
considerBeforeSessionClose{if ((((isNotSessionCloseStarted ()and 
NXSessionParameters::getSessionType ())and Common::NXSessionType::isVirtual (
NXSessionParameters::getSessionType ()))or Common::NXSessionType::isAttach (
NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionClose ();}}}sub
 considerAfterSessionClose{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::afterSessionClose ();}}}sub 
considerBeforeSessionFailure{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionFailure ();}}}
sub considerAfterSessionFailure{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::afterSessionFailure ();}}}
sub setSessionCloseStarted{($NXSession::sessionCloseStarted=
(0x045c+ 7043-0x1fde));}sub isSessionCloseStarted{return (
$NXSession::sessionCloseStarted);}sub isNotSessionCloseStarted{return ((!
isSessionCloseStarted ()));}return ((0x0d86+ 2347-0x16b0));
